pub(super) fn embed_dense(
session: &mut Session,
tokenizer: &Tokenizer,
texts: &[String],
cost_model: &CostModel,
model_variant: ModelVariant,
) -> Result<(Vec<Vec<f32>>, EmbedStats)>Expand description
Produces L2-normalized dense embeddings.
Tokenizes once, then uses the cost model to bin-pack into chunks that fit within the workspace budget. Results are scattered back to the original input order.